73 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
89 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
104 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
119 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
131 void *facet,
int *n1,
int *n2,
int *lx,
132 int *ly,
int *lz,
int *m,
136 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
139 ((
real *)
a, (
real *) b, (
int *)
mask, (
int *) facet, *n1, *n2, *lx,
167 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
181 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
196 const dim3 nblcks(((*mask_size) + 1024 - 1) / 1024, 1, 1);
216 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
229 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
243 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
256 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
270 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
284 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
300 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
314 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
328 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
342 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
358 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
373 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
388 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
403 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
419 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
437 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
453 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
470 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
487 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
504 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
520 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
533 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
547 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
561 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
574 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
588 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
603 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
617 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
631 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
646 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
661 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
673 void *v1,
void *v2,
void *v3,
int *n,
677 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
690 void *v1,
void *v2,
void *v3,
691 void *w1,
void *w2,
void *
w3,
695 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
739 if (
sizeof(
real) ==
sizeof(
float)) {
744 else if (
sizeof(
real) ==
sizeof(
double)) {
776 if (
sizeof(
real_xp) ==
sizeof(
float)) {
781 else if (
sizeof(
real_xp) ==
sizeof(
double)) {
813 if (
sizeof(
real) ==
sizeof(
float)) {
818 else if (
sizeof(
real) ==
sizeof(
double)) {
850 if (
sizeof(
real) ==
sizeof(
float)) {
855 else if (
sizeof(
real) ==
sizeof(
double)) {
882 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
883 const int nb = ((*n) + 1024 - 1)/ 1024;
910 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
911 const int nb = ((*n) + 1024 - 1)/ 1024;
940 const int nt = 1024/
pow2;
943 const int nb = ((*n) + nt - 1)/nt;
969 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
970 const int nb = ((*n) + 1024 - 1)/ 1024;
998 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
999 const int nb = ((*n) + 1024 - 1)/ 1024;
1026 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
1027 const int nb = ((*n) + 1024 - 1)/ 1024;
1053 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
1054 const int nb = ((*n) + 1024 - 1)/ 1024;
1082 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
1083 const int nb = ((*n) + 1024 - 1)/ 1024;
1111 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
1112 const int nb = ((*n) + 1024 - 1)/ 1024;
1142 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
1160 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1174 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1188 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1191 ((
real *)
a, *c, *n);
1202 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1216 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1230 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1244 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1257 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
1272 const dim3 nblcks(((*n)+1024 - 1)/ 1024, 1, 1);
1275 ((
int *)
a, *c, *n);
void cuda_buffer_reserve(cuda_buffer_t *buf, size_t size)
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w
__global__ void const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
#define CUDA_BUFFER_INIT_SYMM
__global__ void const T *__restrict__ x
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w3
#define MASKED_ATOMIC_RED_BLOCK
void device_mpi_allreduce(void *buf_d, void *buf, int count, int nbytes, int op)
void device_nccl_allreduce(void *sbuf_d, void *rbuf_d, int count, int nbytes, int op, void *stream)
void cuda_global_reduce_min(real *bufred, void *bufred_d, int n, const cudaStream_t stream)
void cuda_pwmax_sca3(void *a, void *b, real *c, int *n, cudaStream_t stream)
void cuda_sqrt_inplace(void *a, int *n, cudaStream_t strm)
void cuda_addcol4(void *a, void *b, void *c, void *d, int *n, cudaStream_t strm)
void cuda_add2s2(void *a, void *b, real *c1, int *n, cudaStream_t strm)
void cuda_vdot3(void *dot, void *u1, void *u2, void *u3, void *v1, void *v2, void *v3, int *n, cudaStream_t strm)
void cuda_add3s2(void *a, void *b, void *c, real *c1, real *c2, int *n, cudaStream_t strm)
void cuda_face_masked_gather_copy(void *a, void *b, void *mask, void *facet, int *n1, int *n2, int *lx, int *ly, int *lz, int *m, cudaStream_t strm)
void cuda_global_reduce_add(real *bufred, void *bufred_d, int n, const cudaStream_t stream)
void cuda_addcol3(void *a, void *b, void *c, int *n, cudaStream_t strm)
void cuda_pwmin_vec2(void *a, void *b, int *n, cudaStream_t stream)
void cuda_pwmax_vec3(void *a, void *b, void *c, int *n, cudaStream_t stream)
void cuda_power(void *ap, void *a, real *p, int *n, cudaStream_t strm)
real cuda_glmin(void *a, real *pinf, int *n, cudaStream_t stream)
void cuda_cmult2(void *a, void *b, real *c, int *n, cudaStream_t strm)
void cuda_add2s1(void *a, void *b, real *c1, int *n, cudaStream_t strm)
void cuda_col3(void *a, void *b, void *c, int *n, cudaStream_t strm)
void cuda_masked_copy_0(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
void cuda_add2s2_many(void *x, void **p, void *alpha, int *j, int *n, cudaStream_t strm)
void cuda_sub3(void *a, void *b, void *c, int *n, cudaStream_t strm)
void cuda_copy(void *a, void *b, int *n, cudaStream_t strm)
void cuda_cfill_mask(void *a, real *c, int *size, int *mask, int *mask_size, cudaStream_t strm)
real_xp cuda_glsc3(void *a, void *b, void *c, int *n, cudaStream_t stream)
void cuda_masked_copy_aligned(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
void cuda_invcol2(void *a, void *b, int *n, cudaStream_t strm)
void cuda_global_reduce_add_xp(real_xp *bufred, void *bufred_d, int n, const cudaStream_t stream)
void cuda_pwmax_sca2(void *a, real *c, int *n, cudaStream_t stream)
void cuda_col2(void *a, void *b, int *n, cudaStream_t strm)
void cuda_masked_scatter_copy(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
void cuda_add2(void *a, void *b, int *n, cudaStream_t strm)
void cuda_redbuf_check_alloc(int nb)
void cuda_cmult(void *a, real *c, int *n, cudaStream_t strm)
void cuda_add4(void *a, void *b, void *c, void *d, int *n, cudaStream_t strm)
void cuda_masked_scatter_copy_aligned(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
void cuda_sub2(void *a, void *b, int *n, cudaStream_t strm)
void cuda_redbuf_check_alloc_xp(int nb)
void cuda_invcol3(void *a, void *b, void *c, int *n, cudaStream_t strm)
void cuda_vcross(void *u1, void *u2, void *u3, void *v1, void *v2, void *v3, void *w1, void *w2, void *w3, int *n, cudaStream_t strm)
real_xp cuda_glsc2(void *a, void *b, int *n, cudaStream_t stream)
void cuda_masked_gather_copy(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
real cuda_vlsc3(void *u, void *v, void *w, int *n, cudaStream_t stream)
void cuda_pwmin_sca3(void *a, void *b, real *c, int *n, cudaStream_t stream)
void cuda_cadd2(void *a, void *b, real *c, int *n, cudaStream_t strm)
void cuda_addsqr2s2(void *a, void *b, real *c1, int *n, cudaStream_t strm)
real_xp cuda_glsum(void *a, int *n, cudaStream_t stream)
void cuda_add3(void *a, void *b, void *c, int *n, cudaStream_t strm)
void cuda_addcol3s2(void *a, void *b, void *c, real *s, int *n, cudaStream_t strm)
void cuda_cwrap(void *a, real *min_val, real *max_val, int *n, cudaStream_t strm)
void cuda_pwmin_sca2(void *a, real *c, int *n, cudaStream_t stream)
void cuda_cfill(void *a, real *c, int *n, cudaStream_t strm)
void cuda_absval(void *a, int *n, cudaStream_t stream)
void cuda_rzero(void *a, int *n, cudaStream_t strm)
void cuda_cdiv2(void *a, void *b, real *c, int *n, cudaStream_t strm)
void cuda_cdiv(void *a, real *c, int *n, cudaStream_t strm)
real cuda_glamax(void *a, int *n, cudaStream_t stream)
void cuda_global_reduce_max(real *bufred, void *bufred_d, int n, const cudaStream_t stream)
void cuda_iadd(void *a, int *c, int *n, cudaStream_t stream)
void cuda_masked_gather_copy_aligned(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
void cuda_pwmax_vec2(void *a, void *b, int *n, cudaStream_t stream)
void cuda_glsc3_many(real_xp *h, void *w, void *v, void *mult, int *j, int *n, cudaStream_t stream)
real_xp cuda_glsubnorm2(void *a, void *b, int *n, cudaStream_t stream)
void cuda_masked_atomic_reduction(void *a, void *b, void *mask, int *n, int *m, cudaStream_t strm)
void cuda_add5s4(void *a, void *b, void *c, void *d, void *e, real *c1, real *c2, real *c3, real *c4, int *n, cudaStream_t strm)
void cuda_invcol1(void *a, int *n, cudaStream_t strm)
void cuda_radd(void *a, real *c, int *n, cudaStream_t strm)
void cuda_add4s3(void *a, void *b, void *c, void *d, real *c1, real *c2, real *c3, int *n, cudaStream_t strm)
real cuda_glmax(void *a, real *ninf, int *n, cudaStream_t stream)
void cuda_subcol3(void *a, void *b, void *c, int *n, cudaStream_t strm)
void cuda_pwmin_vec3(void *a, void *b, void *c, int *n, cudaStream_t stream)
Object for handling masks in Neko.